@@ -1,3 +1,4 @@
+import importlib.util
 import json
 import logging
 import os
@@ -6,65 +7,13 @@ import sys
 os.environ["PIP_PYTHON_PATH"] = str(sys.executable)
 
 
-def find_site_path(pkg, site_dir=None):
-    import pkg_resources
-
-    if site_dir is None:
-        site_dir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
-    working_set = pkg_resources.WorkingSet([site_dir] + sys.path[:])
-    for dist in working_set:
-        root = dist.location
-        base_name = dist.project_name if dist.project_name else dist.key
-        name = None
-        if "top_level.txt" in dist.metadata_listdir(""):
-            name = next(
-                iter(
-                    [
-                        line.strip()
-                        for line in dist.get_metadata_lines("top_level.txt")
-                        if line is not None
-                    ]
-                ),
-                None,
-            )
-        if name is None:
-            name = pkg_resources.safe_name(base_name).replace("-", "_")
-        if not any(pkg == _ for _ in [base_name, name]):
-            continue
-        path_options = [name, f"{name}.py"]
-        path_options = [os.path.join(root, p) for p in path_options if p is not None]
-        path = next(iter(p for p in path_options if os.path.exists(p)), None)
-        if path is not None:
-            return dist, path
-    return None, None
-
-
-def _patch_path(pipenv_site=None):
-    import site
-
-    pipenv_libdir = os.path.dirname(os.path.abspath(__file__))
-    pipenv_site_dir = os.path.dirname(pipenv_libdir)
-    if pipenv_site is not None:
-        pipenv_dist, pipenv_path = find_site_path("pipenv", site_dir=pipenv_site)
-    else:
-        pipenv_dist, pipenv_path = find_site_path("pipenv", site_dir=pipenv_site_dir)
-    if pipenv_dist is not None:
-        pipenv_dist.activate()
-    else:
-        site.addsitedir(
-            next(
-                iter(
-                    sitedir
-                    for sitedir in (pipenv_site, pipenv_site_dir)
-                    if sitedir is not None
-                ),
-                None,
-            )
-        )
-    if pipenv_path is not None:
-        pipenv_libdir = pipenv_path
-    for _dir in ("vendor", "patched", pipenv_libdir):
-        sys.path.insert(0, os.path.join(pipenv_libdir, _dir))
+def _ensure_modules():
+    spec = importlib.util.spec_from_file_location(
+        "pipenv", location=os.path.join(os.path.dirname(__file__), "__init__.py")
+    )
+    pipenv = importlib.util.module_from_spec(spec)
+    sys.modules["pipenv"] = pipenv
+    spec.loader.exec_module(pipenv)
 
 
 def get_parser():
@@ -74,7 +23,12 @@ def get_parser():
     parser.add_argument("--pre", action="store_true", default=False)
     parser.add_argument("--clear", action="store_true", default=False)
     parser.add_argument("--verbose", "-v", action="count", default=False)
-    parser.add_argument("--dev", action="store_true", default=False)
+    parser.add_argument(
+        "--category",
+        metavar="category",
+        action="store",
+        default=None,
+    )
     parser.add_argument("--debug", action="store_true", default=False)
     parser.add_argument("--system", action="store_true", default=False)
     parser.add_argument("--parse-only", action="store_true", default=False)
@@ -137,8 +91,13 @@ def handle_parsed_args(parsed):
 class Entry:
     """A resolved entry from a resolver run"""
 
-    def __init__(self, name, entry_dict, project, resolver, reverse_deps=None, dev=False):
+    def __init__(
+        self, name, entry_dict, project, resolver, reverse_deps=None, category=None
+    ):
         super().__init__()
+        from pipenv.utils.dependencies import (
+            get_lockfile_section_using_pipfile_category,
+        )
         from pipenv.vendor.requirementslib.models.utils import tomlkit_value_to_python
 
         self.name = name
@@ -147,15 +106,14 @@ class Entry:
         else:
             self.entry_dict = entry_dict
         self.project = project
-        section = "develop" if dev else "default"
-        pipfile_section = "dev-packages" if dev else "packages"
-        self.dev = dev
-        self.pipfile = tomlkit_value_to_python(
-            project.parsed_pipfile.get(pipfile_section, {})
-        )
-        self.lockfile = project.lockfile_content.get(section, {})
+        self.category = category
+        self.lockfile_section = get_lockfile_section_using_pipfile_category(category)
+        self.pipfile = tomlkit_value_to_python(project.parsed_pipfile.get(category, {}))
+        self.lockfile = project.lockfile_content.get(self.lockfile_section, {})
         self.pipfile_dict = self.pipfile.get(self.pipfile_name, {})
-        if self.dev and self.name in project.lockfile_content.get("default", {}):
+        if self.category != "packages" and self.name in project.lockfile_content.get(
+            "default", {}
+        ):
             self.lockfile_dict = project.lockfile_content["default"][name]
         else:
             self.lockfile_dict = self.lockfile.get(name, entry_dict)
@@ -327,7 +285,7 @@ class Entry:
 
     @property
     def pipfile_name(self):
-        return self.project.get_package_name_in_pipfile(self.name, dev=self.dev)
+        return self.project.get_package_name_in_pipfile(self.name, category=self.category)
 
     @property
     def is_in_pipfile(self):
@@ -335,11 +293,11 @@ class Entry:
 
     @property
     def pipfile_packages(self):
-        return self.project.pipfile_package_names["dev" if self.dev else "default"]
+        return self.project.pipfile_package_names[self.category]
 
     def create_parent(self, name, specifier="*"):
         parent = self.create(
-            name, specifier, self.project, self.resolver, self.reverse_deps, self.dev
+            name, specifier, self.project, self.resolver, self.reverse_deps, self.category
         )
         parent._deptree = self.deptree
         return parent
@@ -351,8 +309,10 @@ class Entry:
         return self._deptree
 
     @classmethod
-    def create(cls, name, entry_dict, project, resolver, reverse_deps=None, dev=False):
-        return cls(name, entry_dict, project, resolver, reverse_deps, dev)
+    def create(
+        cls, name, entry_dict, project, resolver, reverse_deps=None, category=None
+    ):
+        return cls(name, entry_dict, project, resolver, reverse_deps, category)
 
     @staticmethod
     def clean_specifier(specifier):
@@ -641,48 +601,64 @@ class Entry:
         return super().__getattribute__(key)
 
 
-def clean_results(results, resolver, project, dev=False):
-    from pipenv.utils.dependencies import translate_markers
+def clean_results(results, resolver, project, category):
+    from pipenv.utils.dependencies import (
+        get_lockfile_section_using_pipfile_category,
+        translate_markers,
+    )
 
     if not project.lockfile_exists:
         return results
     lockfile = project.lockfile_content
-    section = "develop" if dev else "default"
+    lockfile_section = get_lockfile_section_using_pipfile_category(category)
     reverse_deps = project.environment.reverse_dependencies()
-    new_results = [r for r in results if r["name"] not in lockfile[section]]
+    new_results = [
+        r for r in results if r["name"] not in lockfile.get(lockfile_section, {})
+    ]
     for result in results:
         name = result.get("name")
         entry_dict = result.copy()
         entry = Entry(
-            name, entry_dict, project, resolver, reverse_deps=reverse_deps, dev=dev
+            name,
+            entry_dict,
+            project,
+            resolver,
+            reverse_deps=reverse_deps,
+            category=category,
         )
         entry_dict = translate_markers(entry.get_cleaned_dict(keep_outdated=False))
         new_results.append(entry_dict)
     return new_results
 
 
-def clean_outdated(results, resolver, project, dev=False):
+def clean_outdated(results, resolver, project, category):
+    from pipenv.utils.dependencies import get_lockfile_section_using_pipfile_category
+
     if not project.lockfile_exists:
         return results
     lockfile = project.lockfile_content
-    section = "develop" if dev else "default"
+    lockfile_section = get_lockfile_section_using_pipfile_category(category)
     reverse_deps = project.environment.reverse_dependencies()
-    new_results = [r for r in results if r["name"] not in lockfile[section]]
+    new_results = [r for r in results if r["name"] not in lockfile[lockfile_section]]
     for result in results:
         name = result.get("name")
         entry_dict = result.copy()
         entry = Entry(
-            name, entry_dict, project, resolver, reverse_deps=reverse_deps, dev=dev
+            name,
+            entry_dict,
+            project,
+            resolver,
+            reverse_deps=reverse_deps,
+            category=category,
         )
         # The old entry was editable but this one isnt; prefer the old one
         # TODO: Should this be the case for all locking?
         if entry.was_editable and not entry.is_editable:
             continue
-        lockfile_entry = lockfile[section].get(name, None)
+        lockfile_entry = lockfile[lockfile_section].get(name, None)
         if not lockfile_entry:
-            alternate_section = "develop" if not dev else "default"
-            if name in lockfile[alternate_section]:
-                lockfile_entry = lockfile[alternate_section][name]
+            if name in lockfile[lockfile_section]:
+                lockfile_entry = lockfile[lockfile_section][name]
         if lockfile_entry and not entry.is_updated:
             old_markers = next(
                 iter(
@@ -744,25 +720,27 @@ def parse_packages(packages, pre, clear, system, requirements_dir=None):
         print(json.dumps([]))
 
 
-def resolve_packages(pre, clear, verbose, system, write, requirements_dir, packages, dev):
+def resolve_packages(
+    pre, clear, verbose, system, write, requirements_dir, packages, category
+):
     from pipenv.utils.internet import create_mirror_source, replace_pypi_sources
     from pipenv.utils.resolver import resolve_deps
 
     pypi_mirror_source = (
-        create_mirror_source(os.environ["PIPENV_PYPI_MIRROR"])
+        create_mirror_source(os.environ["PIPENV_PYPI_MIRROR"], "pypi_mirror")
         if "PIPENV_PYPI_MIRROR" in os.environ
         else None
     )
 
     def resolve(
-        packages, pre, project, sources, clear, system, dev, requirements_dir=None
+        packages, pre, project, sources, clear, system, category, requirements_dir=None
     ):
         return resolve_deps(
             packages,
             which,
             project=project,
             pre=pre,
-            dev=dev,
+            category=category,
             sources=sources,
             clear=clear,
             allow_global=system,
@@ -773,15 +751,15 @@ def resolve_packages(pre, clear, verbose, system, write, requirements_dir, packa
 
     project = Project()
     sources = (
-        replace_pypi_sources(project.pipfile_sources, pypi_mirror_source)
+        replace_pypi_sources(project.pipfile_sources(), pypi_mirror_source)
         if pypi_mirror_source
-        else project.pipfile_sources
+        else project.pipfile_sources()
     )
     keep_outdated = os.environ.get("PIPENV_KEEP_OUTDATED", False)
     results, resolver = resolve(
         packages,
         pre=pre,
-        dev=dev,
+        category=category,
         project=project,
         sources=sources,
         clear=clear,
@@ -789,9 +767,9 @@ def resolve_packages(pre, clear, verbose, system, write, requirements_dir, packa
         requirements_dir=requirements_dir,
     )
     if keep_outdated:
-        results = clean_outdated(results, resolver, project, dev)
+        results = clean_outdated(results, resolver, project, category)
     else:
-        results = clean_results(results, resolver, project, dev)
+        results = clean_results(results, resolver, project, category)
     if write:
         with open(write, "w") as fh:
             if not results:
@@ -815,7 +793,7 @@ def _main(
     requirements_dir,
     packages,
     parse_only=False,
-    dev=False,
+    category=None,
 ):
     os.environ["PIPENV_REQUESTED_PYTHON_VERSION"] = ".".join(
         [str(s) for s in sys.version_info[:3]]
@@ -831,21 +809,21 @@ def _main(
         )
     else:
         resolve_packages(
-            pre, clear, verbose, system, write, requirements_dir, packages, dev
+            pre, clear, verbose, system, write, requirements_dir, packages, category
         )
 
 
 def main(argv=None):
     parser = get_parser()
     parsed, remaining = parser.parse_known_args(argv)
-    _patch_path(pipenv_site=parsed.pipenv_site)
+    _ensure_modules()
     import warnings
 
-    from pipenv.vendor.vistir.misc import replace_with_text_stream
+    from pipenv.vendor.click.utils import get_text_stream
 
     warnings.simplefilter("ignore", category=ResourceWarning)
-    replace_with_text_stream("stdout")
-    replace_with_text_stream("stderr")
+    sys.stdout = get_text_stream("stdout")
+    sys.stderr = get_text_stream("stderr")
     os.environ["PIP_DISABLE_PIP_VERSION_CHECK"] = "1"
     os.environ["PYTHONIOENCODING"] = "utf-8"
     os.environ["PYTHONUNBUFFERED"] = "1"
@@ -859,7 +837,7 @@ def main(argv=None):
         parsed.requirements_dir,
         parsed.packages,
         parse_only=parsed.parse_only,
-        dev=parsed.dev,
+        category=parsed.category,
     )
 
 
